/* Converted to NT8 by QTradez.com (Dreamgineering, LLC) - 25 June 2017  

6 November '17 - Added Draw.Region to fill in the cloud and extra code to help draw the span trasnistions as close as possible.
                This version works equally well as an indicator on a chart or reflected in an AddOn.

31 July '17 - Further adjustments needed, but everything works now.  This version is intended for use by strategies and indicators
                since it does not project the cloud in to the future.

27 July '17 - Needed to be able to read values of the cloud so changed the Span data series to plots. This lead to issues
                with the displacement used in NT7.  Fixed by displacing all plots by MediumPeriod and setting values back
                by MediumPeriod 

 */

/* Revisions and Modifications: Zeos6

04/08/11:	Added code to allow selection of up and down band area colors.
10/12/12:	Fixed up some of the properties.
			Added a new reference for the Ichimoku cloud.
			Shifted the cloud forward by an amount equal to the Kijun value.
			Added the Chikou Span, Tenkan Sen, and Kijun Sen lines with the option to display or not display these three lines.
*/

// Added comments, simplied code.	KBJ 30-Oct-2007
//
// For a FULL description of this indicator and how to use it,
// please see:  http://www.kumotrader.com/ichimoku_wiki/
//
// OR
// please see:  http://www.forexabode.com/technical-analysis/ichimoku-cloud
//
// Revised to display the same colors for SenkouSpanA&B as found in above description.	31-Oct-2007
//
// This code was subsequently hacked up by goldfly on 25-Mar-2008

#region Using declarations
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Diagnostics.CodeAnalysis;
using System.Windows;
using System.Reflection;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.Tools;
using NinjaTrader.NinjaScript.DrawingTools;
using NinjaTrader.NinjaScript.Indicators;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.NinjaScript.Indicators
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    public class QT_IchimokuCloud : Indicator
    {
        #region Variables
			private bool	displayCloudOnly			= false;		// Default setting for DisplayCloudOnly.
            private int		periodFast					= 9;			// Default setting for PeriodFast (Tenkan).
            private int		periodMedium				= 26;			// Default setting for PeriodMedium (Kijun).
            private int		periodSlow					= 52;			// Default setting for PeriodSlow (Chikou Span).
			private int		cloudColorOpacity			= 40;			// Value 0 indicates complete transparency. Value 100 indicates complete opacity.
			private Brush	cloudAreaColorUp			= Brushes.Green;	// Default positive cloud area color.
			private Brush	cloudAreaColorDown			= Brushes.Red;  // Default negative cloud area color.
            private Series<double> PreSenkouSpanA, PreSenkouSpanB;
        #endregion

        #region Properties
        #region DataSeries

        [Browsable(false)]
        [XmlIgnore]
        public Series<double> TenkanSen
        {
            get { return Values[0]; }
        }

        [Browsable(false)]
        [XmlIgnore]
        public Series<double> KijunSen
        {
            get { return Values[1]; }
        }

        [Browsable(false)]
        [XmlIgnore]
        public Series<double> ChikouSpan
        {
            get { return Values[2]; }
        }

        [Browsable(false)]
        [XmlIgnore]
        public Series<double> SenkouSpanA
        {
            get { return Values[3]; }
        }

        [Browsable(false)]
        [XmlIgnore]
        public Series<double> SenkouSpanB
        {
            get { return Values[4]; }
        }

        #endregion
        #region Periods

        [NinjaScriptProperty]
        [Display(Name = "Period: Fast (Tenkan Sen)", 
            Description = "Tenkan Sen (conversion line) period.  The default value 9 represents 1.5 Japanese working weeks [at 6 working days per week]. Often set to 7 in countries with 5 day work weeks.", 
            GroupName = "Parameters", Order = 1)]
        public int PeriodFast
        {
            get { return periodFast; }
            set { periodFast = Math.Max(1, value); }
        }

        [NinjaScriptProperty]
        [Display(Name = "Period: Medium (Kijun Sen)", 
            Description = "Kijun Sen (baseline) period.  The default value 26 represents one Japanese working month [at 6 working days per week]. Often set to 22 in countries with 5 day work weeks.", 
            GroupName = "Parameters", Order = 1)]
        public int PeriodMedium
        {
            get { return periodMedium; }
            set { periodMedium = Math.Max(1, value); }
        }

        [NinjaScriptProperty]
        [Display(Name = "Period: Slow (Chikou Span)", 
            Description = "Chikou Span period. The default value 52 represents two Japanese working months [at 6 working days per week]. Often set to 44 in countries with 5 day work weeks.", 
            GroupName = "Parameters", Order = 1)]
        public int PeriodSlow
        {
            get { return periodSlow; }
            set { periodSlow = Math.Max(1, value); }
        }

        #endregion
        #region Visual Params

        [NinjaScriptProperty]
        [Display(Name = "Display Cloud Only?", 
            Description = "If set TRUE, displays only the Senkou Span lines (i.e. the cloud). If set FALSE, displays the Tenkan Sen conversion line, the Kijun Sen base line, and the Chikou Span (lagging span) line in addition to the cloud (i.e. the Senkou Span A and B lines).", 
            GroupName = "Parameters", Order = 1)]
        public bool DisplayCloudOnly
        {
            get { return displayCloudOnly; }
            set { displayCloudOnly = value; }
        }

        [NinjaScriptProperty]
        [Display(Name = "Cloud Color Opacity", 
            Description = "Cloud color opacity. Value 0 indicates complete transparency. Value 100 indicates complete opaqueness.", 
            GroupName = "Colors", Order = 1)]
        public int CloudColorOpacity
        {
            get { return cloudColorOpacity; }
            set { cloudColorOpacity = Math.Min(100, Math.Max(0, value)); }
        }

		[XmlIgnore()]

		[NinjaScriptProperty]
		[Display(Name = "Color of Positive Cloud", 
            Description = "Cloud area color up; i.e. the color of the positive cloud.", 
            GroupName = "Colors", Order = 1)]
        public Brush CloudAreaColorUp
        {
            get { return cloudAreaColorUp; }
            set { cloudAreaColorUp = value; }
        }

		[Browsable(false)]
		public string CloudAreaColorUpSerialize
		{
			get { return Serialize.BrushToString(cloudAreaColorUp); }
			set { cloudAreaColorUp = Serialize.StringToBrush(value); }
		}

		[XmlIgnore()]

		[NinjaScriptProperty]
		[Display(Name = "Color of Negative Cloud", 
            Description = "Cloud area color down; i.e. the color of the negative cloud.", 
            GroupName = "Colors", Order = 1)]
        public Brush CloudAreaColorDown
        {
            get { return cloudAreaColorDown; }
            set { cloudAreaColorDown = value; }
        }

		[Browsable(false)]
		public string CloudAreaColorDownSerialize
		{
			get { return Serialize.BrushToString(cloudAreaColorDown); }
			set { cloudAreaColorDown = Serialize.StringToBrush(value); }
		}
        #endregion
        #endregion
        private void Initialize()
        {
            AddPlot( new Stroke(Brushes.Yellow, 2), PlotStyle.Line,	"TenkanSen");		// Conversion line.
            AddPlot( new Stroke(Brushes.Magenta, 2), PlotStyle.Line,	"KijunSen");	// Base line.
			AddPlot( new Stroke(Brushes.White, 2), PlotStyle.Line,	"ChikouSpan");  	// Lagging span.
            AddPlot(new Stroke(Brushes.Purple, 1), PlotStyle.Line, "SenkouSpanA");    	// Clound span A.
            AddPlot(new Stroke(Brushes.Purple, 1), PlotStyle.Line, "SenkouSpanB");    	// Clound span B.

            PreSenkouSpanA = new Series<double>(this, MaximumBarsLookBack.Infinite);	// Senkou Span A.
            PreSenkouSpanB = new Series<double>(this, MaximumBarsLookBack.Infinite);	// Senkou Span B.

            Calculate	= Calculate.OnBarClose;		// Updated once per bar (as opposed to on every tick.)
            IsOverlay				= true;		// Display on top of the price in panel #1.
            /* NT8 REMOVED: PriceTypeSupported	= false */;
        }

        protected override void OnStateChange()
        {
            switch (State)
            {
                case State.SetDefaults:
                    Name = "QT_IchimokuCloud";
                    Description = "QT_IchimokuCloud Kinko Hyo - \"Equilibrium Chart at a Glance\" - For a FULL description of this indicator and how to use it, please see:  http://www.forexabode.com/technical-analysis/ichimoku-cloud";
                    Initialize();
                    break;

                case State.Configure:
					
                    break;
            }
        }

        private static SolidColorBrush BrushFromArgb(int argb)
        {
            return new SolidColorBrush(Color.FromArgb(
                (byte)(argb >> 24),
                (byte)(argb >> 16),
                (byte)(argb >> 8),
                (byte)(argb)));
        }

        private static SolidColorBrush BrushFromArgb(int alpha, Brush baseBrush)
        {
            var brush = (SolidColorBrush)baseBrush;

            return new SolidColorBrush(Color.FromArgb(
                (byte)alpha,
                brush.Color.R,
                brush.Color.G,
                brush.Color.B));
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if ((CurrentBar < PeriodMedium) || (CurrentBar < PeriodFast))
				return;										// Wait until we have enough bars.

			//
			// The following is a "cloud display" that shows what support/resistance values might be based on prior hi/low averages.
			// The cloud is defined by span-A & span-B.  Span-A is the average of the TenkanSen & Kijunsen, but shifted PeriodMedium
			// bars forward in time, and Span-B is the long-term (slow) average of the lowest-low & highest-high, shifted forward as well.
			//
			if ((CurrentBar < PeriodFast+PeriodMedium) || (CurrentBar < PeriodMedium+PeriodMedium) || (CurrentBar < PeriodSlow+PeriodMedium)) return;

			double fastSum		= MAX(High,PeriodFast)[0] + MIN(Low,PeriodFast)[0];
			double mediumSum	= MAX(High,PeriodMedium)[0] + MIN(Low,PeriodMedium)[0];

        	TenkanSen[0] = fastSum / 2.0;
        	KijunSen[0] = mediumSum / 2.0;
			ChikouSpan[PeriodMedium] = Close[0];

            PreSenkouSpanA[0] = (fastSum + mediumSum) / 4.0;
            PreSenkouSpanB[0] = (MAX(High, PeriodSlow)[0] + MIN(Low, PeriodSlow)[0]) / 2.0;

            if(PreSenkouSpanA.IsValidDataPoint(PeriodMedium) && PreSenkouSpanB.IsValidDataPoint(PeriodMedium))
            {
                SenkouSpanA[0] = PreSenkouSpanA[PeriodMedium];
                SenkouSpanB[0] = PreSenkouSpanB[PeriodMedium];
            }
            else
            {
                SenkouSpanA.Reset();
                SenkouSpanB.Reset();
            }


            if (displayCloudOnly)
			{
				PlotBrushes[0][0] = Brushes.Transparent;
				PlotBrushes[1][0] = Brushes.Transparent;
				PlotBrushes[2][0] = Brushes.Transparent;
			}

            // Fill Cloud add by Dreamgineering, LLC
            Brush FillBrush = Brushes.Transparent;
            if(PreSenkouSpanA.IsValidDataPoint(PeriodMedium + 1))
            {
                if((SenkouSpanA[1] > SenkouSpanB[1] && SenkouSpanA[0] < SenkouSpanB[0])
                    || (SenkouSpanA[1] < SenkouSpanB[1] && SenkouSpanA[0] > SenkouSpanB[0]))
                {
                    if (Math.Abs(SenkouSpanA[1] - SenkouSpanB[1]) > Math.Abs(SenkouSpanA[0] - SenkouSpanB[0]))
                        FillBrush = PreSenkouSpanA.IsValidDataPoint(PeriodMedium) && SenkouSpanA[0] > SenkouSpanB[0] ? CloudAreaColorDown : CloudAreaColorUp;
                    else
                        FillBrush = PreSenkouSpanA.IsValidDataPoint(PeriodMedium) && SenkouSpanA[0] > SenkouSpanB[0] ? CloudAreaColorUp : CloudAreaColorDown;
                }
                else if(SenkouSpanA[0] == SenkouSpanB[0])
                    FillBrush = PreSenkouSpanA.IsValidDataPoint(PeriodMedium) && SenkouSpanA[1] < SenkouSpanB[1] ? CloudAreaColorDown : CloudAreaColorUp;
                else
                    FillBrush = PreSenkouSpanA.IsValidDataPoint(PeriodMedium) && SenkouSpanA[0] < SenkouSpanB[0] ? CloudAreaColorDown : CloudAreaColorUp;
            }

			Draw.Region(this, "Region" + CurrentBar, 1, 0, SenkouSpanA, SenkouSpanB, null, FillBrush, CloudColorOpacity);
        }

        #region New OnRender

        protected void OnRenderNotUsed(ChartControl chartControl, ChartScale chartScale)
        {
            if (Bars == null || ChartControl == null) return;

            if (Brushes.Transparent == CloudAreaColorUp && Brushes.Transparent == CloudAreaColorDown || 0 == CloudColorOpacity)
            {
                base.OnRender(chartControl, chartScale);        // Call base Plot() method to paint defined Plots.
                return;                                         // If cloudAreaColor colors are transparent or cloudColorOpacity is 0
                                                                // there is nothing to paint so return to avoid unnecessary calculations.
            }

            #region initialize variables
            SharpDX.Direct2D1.Brush brush = null;                    // Set up/down brush color and opacity here.
            SharpDX.Direct2D1.Brush brushUP = CloudAreaColorUp.ToDxBrush(RenderTarget);
            brushUP.Opacity = (float)(CloudColorOpacity / 100.0);
            SharpDX.Direct2D1.Brush brushDOWN = CloudAreaColorDown.ToDxBrush(RenderTarget);
            brushDOWN.Opacity = (float)(CloudColorOpacity / 100.0);

            System.Windows.Point p0, p1, p2, p3;
            SharpDX.Vector2 V0 = new SharpDX.Vector2();
            SharpDX.Vector2 V1 = new SharpDX.Vector2();

            SharpDX.Direct2D1.PathGeometry path = new SharpDX.Direct2D1.PathGeometry(Core.Globals.D2DFactory);  // Create a new path.
            SharpDX.Direct2D1.GeometrySink sink = path.Open();
            
            ChartControlProperties myProperties = chartControl.Properties;

            int barWidth = chartControl.GetBarPaintWidth(ChartBars);
            //double barWidth = chartControl.BarWidth;

            brush = brushUP;                                // Start with the upwards color.
            int barcount = 0;                               // Start with leftmost bar.
            bool firstbar = true;                           // Plotting the first bar.
            #endregion
            #region paint bars loop
			
            while (barcount < ChartBars.ToIndex)		// Continue until all bars have been painted.
            {
                #region Plot loop
                int count = 0;                              // Counter for innner loop.
                for (int seriesCount = 0; seriesCount < 2; seriesCount++)
                {
                    int lastX = -1;
                    int lastY = -1;
                    Series<double> series = (0 == seriesCount) ? SenkouSpanA : SenkouSpanB;

                    #region cloud loop
                    //for (count = barcount; count < ChartControl.BarsPainted; count++)
                    for (count = barcount; count < ChartBars.Count; count++)
                    {
                        //int idx = ChartControl.LastBarPainted - ChartBars.Count + 1 + count - BBase;
                        int idx = chartControl.LastSlotPainted - ChartBars.ToIndex + 1 + count - periodMedium;
                        //if (idx < 0 || idx >= Input.Count || (!chartControl.ShowBarsRequired && idx < BarsRequiredToPlot))
                        if (idx < 0 || idx >= Input.Count || (idx < BarsRequiredToPlot))
                            continue;

                        bool SenkouSpanAHasValue = SenkouSpanA.IsValidDataPointAt(idx) && SenkouSpanA.GetValueAt(idx) > 0;
                        bool SenkouSpanBHasValue = SenkouSpanB.IsValidDataPointAt(idx) && SenkouSpanB.GetValueAt(idx) > 0;
                        if (!SenkouSpanAHasValue || !SenkouSpanAHasValue)   // If we don't have valid value for the series then skip the loop step
                                                                        // as there is nothing to plot. So ignore the entry.
                            continue;

                        double val = series.GetValueAt(idx);                       // Get next y-value to be plotted.

                        //int x = (int)(ChartControl.CanvasRight - ChartControl.BarMarginRight - barWidth / 2
                        //      + (count - ChartBars.Count + 1) * ChartControl.BarSpace) + 1;

                        int x = (int)(ChartControl.CanvasRight - myProperties.BarMarginRight - barWidth / 2
                              + (count - ChartBars.Count + 1) * ChartControl.BarWidth) + 1;

                        //int y = (int)((bounds.Y + bounds.Height) - ((val - min) / Gui.Chart.ChartControl.MaxMinusMin(max, min)) * bounds.Height);
                        int y = (int)((chartControl.ChartPanels[0].Y + chartControl.ChartPanels[0].H) - ((val - chartControl.ChartPanels[0].MinValue) / chartControl.ChartPanels[0].H) * chartControl.ChartPanels[0].H);

                        double val0 = SenkouSpanA.GetValueAt(idx);
                        double val1 = SenkouSpanB.GetValueAt(idx);

                        if (((val0 > val1) && (brush != brushUP))   // Now going in wrong direction?
                            || ((val0 < val1) && (brush != brushDOWN)))
                        {                                           // Yes.  Done with this loop.
                            if (lastX >= 0)                         // Was there a last point?
                            {                                       // Yes.  Connect it to the position half-way to this one.
                                                                    //path.AddLine(lastX, lastY, (x + lastX) / 2, (lastY + y) / 2);

                                // build vectos and add as below

                                p1 = new System.Windows.Point(lastX, lastY);
                                p2 = new System.Windows.Point((x + lastX) / 2, (lastY + y) / 2);

                                SharpDX.Vector2[] vectors = new[] { p1.ToVector2(), p2.ToVector2() };

                                //sink.AddLine(lastX, lastY, (x + lastX) / 2, (lastY + y) / 2);
                                sink.AddLines(vectors);
                                // Plot vertex of cross-over of the lines (1/2 way point).
                            }
                            break;                                  // Done, exit inner loop to change color.
                        }

                        if (firstbar == false)                              // Is this the first plotted bar of the chart?
                        {                                                   // No.  Plot all bars after the first one.
                            if (count == barcount)                          // First bar after direction change (and color swap)?
                            {                                               // Yes.  Add line segment for cross-over, 1/2 bar back.
                                double valm1 = series.GetValueAt(idx - 1); 	// Get prior y-value to be plotted.
                                //lastX = x - ChartControl.BarSpace / 2;// Back up 1/2 a bar for x-value.
                                lastX = x - (int)ChartControl.BarWidth / 2;// Back up 1/2 a bar for x-value.
                                lastY = (y + (int)((chartControl.ChartPanels[0].Y + chartControl.ChartPanels[0].H) - ((valm1 - chartControl.ChartPanels[0].MinValue) / chartControl.ChartPanels[0].H) * chartControl.ChartPanels[0].H)) / 2;
                            }

                            // build vectos and add as below

                            p1 = new System.Windows.Point(lastX, lastY);
                            p2 = new System.Windows.Point(x, y);

                            SharpDX.Vector2[] vectors = new[] { p1.ToVector2(), p2.ToVector2() };

                            //sink.BeginFigure(p0.ToVector2(), SharpDX.Direct2D1.FigureBegin.Filled);
                            sink.AddLines(vectors);
                            //sink.AddLine(lastX, lastY, x, y);       // Connect last point to this one.
                        }
                        else // on first bar
                        {
                            p0 = new System.Windows.Point(x, y);
                			sink.BeginFigure(p0.ToVector2(), SharpDX.Direct2D1.FigureBegin.Filled);
                        }
                        firstbar = false;                           // No longer the first bar.
                        lastX = x;                                  // Save current position for next time, so we can connect the dots.
                        lastY = y;
                    }

                    //path.Reverse();                                 // Go back the other direction.
                    //path.Stream();                                 // Go back the other direction.
                    #endregion

                }
                #endregion
				
                sink.EndFigure(SharpDX.Direct2D1.FigureEnd.Closed);
                sink.Close();
                RenderTarget.DrawGeometry(path, brush);
                RenderTarget.FillGeometry(path, brush);


                barcount = count;                                   // Get ready to process next segment.
                brush = (brush == brushUP) ? brushDOWN : brushUP;   // Switch colors for next segment.
            }
            #endregion
            #region clean up
			
            brushUP.Dispose();                                      // Dispose of brushes.
            brushDOWN.Dispose();
			
            path.Dispose();                                         // Dispose of path.
            sink.Dispose();                                         // Dispose of sink.

            base.OnRender(chartControl, chartScale);                // Call the base OnRender() method to paint defined Plots.
            #endregion
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private QT_IchimokuCloud[] cacheQT_IchimokuCloud;
		public QT_IchimokuCloud QT_IchimokuCloud(int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			return QT_IchimokuCloud(Input, periodFast, periodMedium, periodSlow, displayCloudOnly, cloudColorOpacity, cloudAreaColorUp, cloudAreaColorDown);
		}

		public QT_IchimokuCloud QT_IchimokuCloud(ISeries<double> input, int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			if (cacheQT_IchimokuCloud != null)
				for (int idx = 0; idx < cacheQT_IchimokuCloud.Length; idx++)
					if (cacheQT_IchimokuCloud[idx] != null && cacheQT_IchimokuCloud[idx].PeriodFast == periodFast && cacheQT_IchimokuCloud[idx].PeriodMedium == periodMedium && cacheQT_IchimokuCloud[idx].PeriodSlow == periodSlow && cacheQT_IchimokuCloud[idx].DisplayCloudOnly == displayCloudOnly && cacheQT_IchimokuCloud[idx].CloudColorOpacity == cloudColorOpacity && cacheQT_IchimokuCloud[idx].CloudAreaColorUp == cloudAreaColorUp && cacheQT_IchimokuCloud[idx].CloudAreaColorDown == cloudAreaColorDown && cacheQT_IchimokuCloud[idx].EqualsInput(input))
						return cacheQT_IchimokuCloud[idx];
			return CacheIndicator<QT_IchimokuCloud>(new QT_IchimokuCloud(){ PeriodFast = periodFast, PeriodMedium = periodMedium, PeriodSlow = periodSlow, DisplayCloudOnly = displayCloudOnly, CloudColorOpacity = cloudColorOpacity, CloudAreaColorUp = cloudAreaColorUp, CloudAreaColorDown = cloudAreaColorDown }, input, ref cacheQT_IchimokuCloud);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.QT_IchimokuCloud QT_IchimokuCloud(int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			return indicator.QT_IchimokuCloud(Input, periodFast, periodMedium, periodSlow, displayCloudOnly, cloudColorOpacity, cloudAreaColorUp, cloudAreaColorDown);
		}

		public Indicators.QT_IchimokuCloud QT_IchimokuCloud(ISeries<double> input , int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			return indicator.QT_IchimokuCloud(input, periodFast, periodMedium, periodSlow, displayCloudOnly, cloudColorOpacity, cloudAreaColorUp, cloudAreaColorDown);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.QT_IchimokuCloud QT_IchimokuCloud(int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			return indicator.QT_IchimokuCloud(Input, periodFast, periodMedium, periodSlow, displayCloudOnly, cloudColorOpacity, cloudAreaColorUp, cloudAreaColorDown);
		}

		public Indicators.QT_IchimokuCloud QT_IchimokuCloud(ISeries<double> input , int periodFast, int periodMedium, int periodSlow, bool displayCloudOnly, int cloudColorOpacity, Brush cloudAreaColorUp, Brush cloudAreaColorDown)
		{
			return indicator.QT_IchimokuCloud(input, periodFast, periodMedium, periodSlow, displayCloudOnly, cloudColorOpacity, cloudAreaColorUp, cloudAreaColorDown);
		}
	}
}

#endregion
